@@ -5,8 +5,8 @@
 ;; Author: Daniel Mendler <mail@daniel-mendler.de>
 ;; Maintainer: Daniel Mendler <mail@daniel-mendler.de>
 ;; Created: 2021
-;; Version: 2.2
-;; Package-Requires: ((emacs "28.1") (compat "30") (vertico "2.2"))
+;; Version: 2.3
+;; Package-Requires: ((emacs "28.1") (compat "30") (vertico "2.3"))
 ;; URL: https://github.com/minad/vertico
 
 ;; This file is part of GNU Emacs.
@@ -122,6 +122,7 @@ The keys in LIST can be symbols or regexps."
                    (vertico-multiform--toggle -1)
                    (pop vertico-multiform--stack))))
     (add-hook 'minibuffer-exit-hook exit)
+    (add-hook 'context-menu-functions #'vertico-multiform--display-menu nil t)
     (dolist (x (cdr (or (vertico-multiform--lookup this-command vertico-multiform-commands)
                         (vertico-multiform--lookup cat vertico-multiform-categories))))
       (pcase x
@@ -146,14 +147,23 @@ The keys in LIST can be symbols or regexps."
   "Configure Vertico in various forms per command."
   :global t :group 'vertico
   (when (/= (recursion-depth) 0)
-    (warn "vertico-multiform must not be toggled from recursive minibuffers"))
+    (warn "Vertico multiform must not be toggled from recursive minibuffers"))
   (when vertico-multiform--stack
-    (warn "vertico-multiform state is inconsistent")
+    (warn "Vertico multiform state is inconsistent")
     (setq vertico-multiform--stack nil))
   (cl-callf2 rassq-delete-all vertico-multiform-map minor-mode-map-alist)
   (when vertico-multiform-mode
     (push `(vertico--input . ,vertico-multiform-map) minor-mode-map-alist)))
 
+(defvar vertico-multiform--display-modes nil)
+(defvar-local vertico-multiform--display-last nil)
+
+(defun vertico-multiform--display-menu (menu _event)
+  "Add Vertico display modes to MENU."
+  (define-key menu [vertico-multiform--display-menu]
+              `(menu-item "Vertico Display" ,vertico-multiform-map))
+  menu)
+
 (cl-defmethod vertico--advice (&context (vertico-multiform-mode (eql t)) &rest app)
   (unwind-protect
       (progn
@@ -183,9 +193,6 @@ ARG can be nil, t, -1, 1 or toggle."
           (setcar vertico-multiform--stack (remove mode modes))
         (push not-mode (car vertico-multiform--stack))))))
 
-(defvar vertico-multiform--display-modes nil)
-(defvar-local vertico-multiform--display-last nil)
-
 (defun vertico-multiform-vertical (&optional mode)
   "Toggle to display MODE temporarily in minibuffer.
 MODE defaults to the vertical display."
@@ -201,13 +208,10 @@ MODE defaults to the vertical display."
       (vertico-multiform--temporary-mode mode 1))
     (setq vertico-multiform--display-last last)))
 
-(pcase-dolist (`(,key ,name) '(("M-B" buffer)
-                               ("M-F" flat)
-                               ("M-G" grid)
-                               ("M-R" reverse)
-                               ("M-U" unobtrusive) ;; must come after flat
-                               ("M-V" vertical)))
-  (let ((toggle (intern (format "vertico-multiform-%s" name))))
+;; unobtrusive must come after flat
+(dolist (name '(buffer flat grid reverse unobtrusive vertical))
+  (let ((toggle (intern (format "vertico-multiform-%s" name)))
+        (label (capitalize (symbol-name name))))
     (unless (eq name 'vertical)
       (let ((mode (intern (format "vertico-%s-mode" name))))
         (defalias toggle
@@ -215,7 +219,8 @@ MODE defaults to the vertical display."
           (format "Toggle the %s display." name))
         (push mode vertico-multiform--display-modes)))
     (put toggle 'completion-predicate #'vertico--command-p)
-    (keymap-set vertico-multiform-map key toggle)))
+    (define-key vertico-multiform-map (vector toggle) (cons label toggle))
+    (keymap-set vertico-multiform-map (format "M-%c" (aref label 0)) toggle)))
 
 (provide 'vertico-multiform)
 ;;; vertico-multiform.el ends here
